@@ -17,6 +17,10 @@ from invoice_items import (
     InvoiceItem,
     InvoiceItemsIterator
 )
+from invoice_payments import (
+    InvoicePayment,
+    InvoicePaymentsIterator
+)
 from invoice_tags import (
     InvoiceTag,
     InvoiceTagsIterator
@@ -65,3 +69,15 @@ from reminders import (
     Reminder,
     RemindersIterator
 )
+from reminder_items import (
+    ReminderItem,
+    ReminderItemsIterator
+)
+from reminder_tags import (
+    ReminderTag,
+    ReminderTagsIterator
+)
+from reminder_texts import (
+    ReminderText,
+    ReminderTextsIterator
+)
